betty.media_type.media_types module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.media_type.media_types module

Provide media types.

betty.media_type.media_types.HTML = <betty.media_type.MediaType object>

  The media type for HTML content.

betty.media_type.media_types.JSON = <betty.media_type.MediaType object>

  The media type for JSON content.

betty.media_type.media_types.JSON_LD = <betty.media_type.MediaType object>

  The media type for JSON-LD content.

betty.media_type.media_types.PLAIN_TEXT = <betty.media_type.MediaType object>

  The media type for plain text content.

betty.media_type.media_types.SVG = <betty.media_type.MediaType object>

  The media type for SVG images.